@@ -14,24 +14,29 @@ test_that('scto_read dataset not ok', {
 
 test_that('scto_read form ok', {
   skip_on_cran()
-  d = scto_read(auth, 'hh_listing_example_1', 'form')
+  d = scto_read(auth, 'hh_listing_example_1')
   expect_data_table(d)
 })
 
 test_that('scto_read form not ok', {
   skip_on_cran()
-  expect_error(scto_read(
-    auth, 'hh_listing_example_1', 'form', start_date = 'coffee'))
+  expect_error(scto_read(auth, 'hh_listing_example_1', start_date = 'coffee'))
 })
 
 test_that('scto_read form encrypted no key', {
   skip_on_cran()
-  d = scto_read(auth, 'hh_example_encrypted', 'form')
+  d = scto_read(auth, 'hh_example_encrypted')
   expect_data_table(d, ncols = 7L)
 })
 
 test_that('scto_read form encrypted key', {
   skip_on_cran()
-  d = scto_read(auth, 'hh_example_encrypted', 'form', private_key = private_key)
+  d = scto_read(auth, 'hh_example_encrypted', private_key = private_key)
   expect_data_table(d, ncols = 20L)
 })
+
+test_that('scto_read_all ok', {
+  skip_on_cran()
+  db = scto_read_all(auth)
+  expect_list(db, min.len = 1L)
+})
